=begin  
  music.rb
	Copyright (c) 2004 by Jesse van den Kieboom <troplosti@orcaweb.cjb.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
	
	Defines:
	  rb/rhythmbox - show which song rb is currenly playing
=end

def register_functions
  register_func("rhythmbox", "use: /rhythmbox <prefix>|next|prev|play|pause\nsends the song rb is currently playing to the world prefixed by <prefix> or performs the action specified if pause, play, next or prev is specified")
  register_func("rb", "alias for rhythmbox", "rhythmbox")
end

def getOgginfo(filename)
  if (!File.exists?("/usr/bin/ogginfo"))
    return nil
  end
  
  info = `/usr/bin/ogginfo "#{filename}" 2> /dev/null`
  artist = nil
  title = nil
  
  if (!info.empty?)
    info.split("\n").each {|line|
      line = line.strip
      if (line[/^artist=/i])
        artist = line[7..-1]
      elsif (line[/^title=/i])
        title = line[6..-1]
      end
    }
    
    return "#{artist} - #{title}"
  else
    return nil
  end
end

def getID3info(filename)
  if (!File.exists?("/usr/bin/id3info"))
    nil
  end

  info = `/usr/bin/id3info "#{filename}" 2> /dev/null`.split("\n")
  artist = nil
  title = nil
  
  if (info.length == 1 && info[0].empty? == 0)
    return nil
  end
  
  info.each {|line|
    line = line.strip
    if (line.index(/TPE[1|2]/) != nil)
      artist = line[line.index(":") + 1..-1].strip
    elsif (line.index("TIT2") != nil)
      title = line[line.index(":") + 1..-1].strip
    end
  }
  
  if (title && artist)
    return "#{artist} - #{title}"
  else
    return nil
  end
end

def getMP3info(filename)
  if ((info = getID3info(filename)))
    return info
  end
  
  if (!File.exists?("/usr/bin/mp3info"))
    return nil
  end
  
  info = `/usr/bin/mp3info -p "%a - %t" "#{filename}" 2> /dev/null`
  
  if (!info.empty?)  
    return info
  else
    return nil
  end
end

def rhythmbox(argstr)
  isopen = !(`/bin/ps -ae | /bin/grep rhythmbox`.empty?)

  if (!isopen)
    $world.writeln("Script error: rhythmbox is not running!")
    return
  end
  
  if (argstr == "next")
    `/usr/bin/rhythmbox --next`
  elsif (argstr == "prev")
    `/usr/bin/rhythmbox --previous`
  elsif (argstr == "play" || argstr == "pause")
    `/usr/bin/rhythmbox --play-pause`
  else      
    path = `/usr/bin/rhythmbox --print-playing-path 2> /dev/null`
    info = nil
  
    if (!path.empty?)
      filename = path.split("\n")[0].gsub(/%20/, " ")[7..-1]
      
      if (filename[-3..-1] == "mp3" && (info = getMP3info(filename)))
      elsif (filename[-3..-1] == "ogg" && (info = getOgginfo(filename)))
      else
        info = `/usr/bin/rhythmbox --print-playing 2> /dev/null`
      
        if (!info.empty?)
          info = info.split("\n")[0]
        else
          info = nil
        end 
      end
    
      if (info)
        $world.sendln(argstr + " :luistert op dit moment naar [ #{info} ]")
      else
        $world.writeln("Script error: cannot retrieve rhythmbox file play")
      end  
    
    else
      $world.writeln("Script error: can not execute /usr/bin/rhythmbox!")
    end
  end
end
